/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.apisix.plugin.runner;

import org.apache.apisix.plugin.runner.filter.PluginFilterChain;

import java.util.Map;

public class A6Conf {

    public Map<String, String> getConfig() {
        return config;
    }

    private final Map<String, String> config;

    public PluginFilterChain getChain() {
        return chain;
    }

    private final PluginFilterChain chain;

    public A6Conf(Map<String, String> config, PluginFilterChain chain) {
        this.config = config;
        this.chain = chain;
    }

    public String get(String key) {
        return config.getOrDefault(key, null);
    }
}
